{%- set author = authors | first -%}

{% block title %}
## {{ role.name }}
{% endblock %}

{% block badges %}
{% if ansigenome_info.travis is defined and ansigenome_info.travis %}[![Travis CI](http://img.shields.io/travis/{{ scm.user + '/' + role.slug }}.svg?style=flat)](http://travis-ci.org/{{ scm.user + '/' + role.slug }}){% endif %} {% if ansigenome_info.galaxy_id is defined and ansigenome_info.galaxy_id %} [![Ansible Galaxy](http://img.shields.io/badge/galaxy-{{ role.galaxy_name | replace('-', '–')}}-660198.svg?style=flat)](https://galaxy.ansible.com/list#/roles/{{ ansigenome_info.galaxy_id }}){% endif %}{% if galaxy_info.platforms is defined and galaxy_info.platforms %} [![Platforms](http://img.shields.io/badge/platforms-{{ galaxy_info.platforms | map(attribute='name') | sort | join('%20/%20') | lower }}-lightgrey.svg?style=flat)](#){% endif %}
{% endblock %}

{% if ansigenome_info.beta is defined and ansigenome_info.beta %}
{% block beta %}
### Warning, this is a BETA role

This role has been marked by the author as a beta role, which means that it
might be significantly changed in the future. Be careful while using this role
in a production environment.

***
{% endblock %}
{% endif %}

{% if ansigenome_info.synopsis is defined %}
{% block synopsis %}
{{ ansigenome_info.synopsis | trim }}
{% endblock %}
{% endif %}

{% if ansigenome_info.galaxy_id is defined and ansigenome_info.galaxy_id %}
{% block installation %}
### Installation

This role requires at least Ansible{% if galaxy_info.min_ansible_version is defined and galaxy_info.min_ansible_version %} `v{{ galaxy_info.min_ansible_version }}`{% endif %}. To install it, run:

    ansible-galaxy install {{ role.galaxy_name }}
{% endblock %}
{% endif %}

{% if dependencies is defined and dependencies -%}
{% block dependencies %}
### Role dependencies

{% for dependency in dependencies | unique_dict("role") %}
- `{{ dependency.role | trim }}`{% endfor %}
{% endblock %}
{% endif %}

{% if ansigenome_info.defaults is defined and ansigenome_info.defaults %}

### Role variables

List of default variables available in the inventory:

{{ ansigenome_info.defaults | trim | indent(4, true) }}
{% endif %}

{% if ansigenome_info.facts is defined and ansigenome_info.facts %}
List of internal variables used by the role:

{{ ansigenome_info.facts | trim | indent(4, true) }}{% endif %}

{% if ansigenome_info.usage is defined and ansigenome_info.usage %}
{% block usage %}
### Detailed usage guide

{{ ansigenome_info.usage | trim }}
{% endblock %}
{% endif %}

{% if ansigenome_info.custom is defined and ansigenome_info.custom %}

{{ ansigenome_info.custom | trim }}{% endif %}

{% block authors %}
### Authors and license

`{{ role.name }}` role was written by:
{% for credit in authors %}
- {% if credit.url is defined and credit.url %}[{% endif %}{{ credit.name }}{% if credit.url is defined and credit.url %}]({{ credit.url }}){% endif %}{% if credit.email is defined and credit.email %} | [e-mail](mailto:{{ credit.email }}){% endif %}{% if credit.twitter is defined and credit.twitter %} | [Twitter](https://twitter.com/{{ credit.twitter }}){% endif %}{% if credit.github is defined and credit.github %} | [GitHub](https://github.com/{{ credit.github }}){% endif %}
{% endfor %}
License: [{{ license.type | trim }}]({{ license.url | trim }})
{% endblock %}

{% block footer %}
***

README generated by [Ansigenome](https://github.com/nickjj/ansigenome/).
{% endblock %}
